@@ -1,13 +1,11 @@
 # [[[ HEADER ]]]
+use RPerl;
 package RPerl::Test::LiteralString::Package_DoubleQuotes_08_Good;
 use strict;
 use warnings;
-use RPerl;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our string $empty_sub = sub {
-    return "\n\nfoo\n\nbar\n\n";
-};
+our string $empty_sub = sub { return "\n\nfoo\n\nbar\n\n"; };
 
 1;    # end of package
