@@ -6,8 +6,6 @@ use warnings;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our string $empty_sub = sub {
-    return '"foo123"';
-};
+our string $empty_sub = sub { return '"foo123"'; };
 
 1;    # end of package
