@@ -16,5 +16,5 @@ our $VERSION = 0.001_000;
 
 # [[[ OPERATIONS ]]]
 
-# DEV NOTE: DO NOT RUN PERLTIDY ON THIS FILE!  the line below should read 'die(...' not 'die (...'
-die( @{ [2] }, "\n" );
\ No newline at end of file
+# DEV NOTE: DO NOT RUN PERLTIDY ON THIS FILE!  the line below should read 'die (...);' not 'die(...);'
+die ( @{ [ 2, 3, 5, 7 ] }, "\n" );
