@@ -10,9 +10,7 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-our boolean $foo = sub {
-    return 1;
-};
+our boolean $foo = sub { return 1; };
 
 # [[[ OPERATIONS ]]]
 foo();
