@@ -10,9 +10,7 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-our integer_arrayref $foo = sub {
-    return [ 2, 3, 5, 7 ];
-};
+our integer_arrayref $foo = sub { return [ 2, 3, 5, 7 ]; };
 
 # [[[ OPERATIONS ]]]
 foo();
