@@ -6,9 +6,6 @@ use warnings;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub {
-    ( my number $foo, my string $bar, my scalartype_arrayref $baz, my integer_hashref $bat ) = @ARG;
-    return 1;
-};
+our void $empty_sub = sub { ( my number $foo, my string $bar, my scalartype_arrayref $baz, my integer_hashref $bat ) = @ARG; return 1; };
 
 1;    # end of package
